@@ -140,10 +140,7 @@ def test_well_path_safe_repr():
 
 def test_well_path_safe_repr_keep_prefix():
     well = Well(28255, unit_no="6528-1127", obs_no="YAT124")
-    assert (
-        well.path_safe_repr(remove_prefix=False)
-        == "'YAT124'"
-    )
+    assert well.path_safe_repr(remove_prefix=False) == "'YAT124'"
 
 
 def test_well_name():
@@ -198,5 +195,6 @@ def test_well_bool():
     well = Well(203536, unit_no="6627-11249")
     assert well
 
+
 def test_well_with_property_kwarg():
-    well = Well(203536, unit_no=662711249, unit_hyphen="6627-11249")
\ No newline at end of file
+    well = Well(203536, unit_no=662711249, unit_hyphen="6627-11249")
